@@ -17,8 +17,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef PROCESSCORE_DEBUG_H
-#define PROCESSCORE_DEBUG_H
+#ifndef POWERDEVIL_DEBUG_H
+#define POWERDEVIL_DEBUG_H
 
 #include <QLoggingCategory>
 Q_DECLARE_LOGGING_CATEGORY(POWERDEVIL)
