@@ -654,8 +654,8 @@ bool PolicyAgent::HasInhibition(/*PolicyAgent::RequiredPolicies*/ uint types)
 
 void PolicyAgent::releaseAllInhibitions()
 {
-    QList< uint > allCookies = m_cookieToAppName.keys();
-    Q_FOREACH (uint cookie, allCookies) {
+    const QList< uint > allCookies = m_cookieToAppName.keys();
+    for (uint cookie : allCookies) {
         ReleaseInhibition(cookie);
     }
 }
@@ -669,8 +669,8 @@ void PolicyAgent::setupSystemdInhibition()
         return;
 
     // inhibit systemd/ConsoleKit2 handling of power/sleep/lid buttons
-    // http://www.freedesktop.org/wiki/Software/systemd/inhibit
-    // http://consolekit2.github.io/ConsoleKit2/#Manager.Inhibit
+    // https://www.freedesktop.org/wiki/Software/systemd/inhibit
+    // https://consolekit2.github.io/ConsoleKit2/#Manager.Inhibit
     qCDebug(POWERDEVIL) << "fd passing available:" << bool(m_managerIface.data()->connection().connectionCapabilities() & QDBusConnection::UnixFileDescriptorPassing);
 
     QVariantList args;
